Chess Self-Coach

Sample data — Install the app to train on your own games

Loading training data...

See moves played during the game

Analyzing...

Select all
← Back to games list
0.0

## Settings

Training Positions per session: Hint depth: Difficulty:
Accounts Lichess username: Chess.com username:
Analysis Analysis depth: Blunder threshold (pawns): Games to fetch:
Analysis speed:
Advanced engine settings
Threads: Hash (MB):

#### Depth / time limits by position type

K+P endgame: depth time (s) Endgame: depth time (s) Late middlegame: depth time (s) Default: depth

#### Danger zone

## Session Complete

## Chess Self-Coach

## Fetch games

games